@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021 -- leonerd@leonerd.org.uk
 
-package Syntax::Operator::Equ 0.04;
+package Syntax::Operator::Equ 0.05;
 
 use v5.14;
 use warnings;
@@ -19,7 +19,7 @@ C<Syntax::Operator::Equ> - equality operators that distinguish C<undef>
 
 =head1 SYNOPSIS
 
-On a suitably-patched perl:
+On a suitable perl version:
 
    use Syntax::Operator::Equ;
 
@@ -55,14 +55,15 @@ yield true if both operands are C<undef>, false if exactly one operand is, or
 otherwise behave the same as the regular string or number equality tests if
 both operands are defined.
 
-Current versions of perl do not directly support custom infix operators. The
-documentation of L<XS::Parse::Infix> describes the situation, with reference
-to a branch experimenting with this new feature. This module is therefore
-I<almost> entirely useless on standard perl builds. While the regular parser
-does not support custom infix operators, they are supported via
-C<XS::Parse::Infix> and hence L<XS::Parse::Keyword>, and so custom keywords
-which attempt to parse operator syntax may be able to use it. One such module
-is L<Syntax::Keyword::Match>; see the SYNOPSIS example given above.
+Current stable versions of perl do not directly support custom infix
+operators, but the ability was added in the 5.37.x development cycle and is
+available from perl v5.37.7 onwards. The documentation of L<XS::Parse::Infix>
+describes the situation in more detail. This module is therefore I<almost>
+entirely useless on stable perl builds. While the regular parser does not
+support custom infix operators, they are supported via C<XS::Parse::Infix> and
+hence L<XS::Parse::Keyword>, and so custom keywords which attempt to parse
+operator syntax may be able to use it. One such module is
+L<Syntax::Keyword::Match>; see the SYNOPSIS example given above.
 
 =cut
 
